PackageMetadata

Struct PackageMetadata 

pub struct PackageMetadata {
    pub name: String,
    pub version: String,
    pub license: Option<String>,
    pub description: Option<String>,
    pub documentation: Option<String>,
    pub authors: Vec<String>,
    /* private fields */
}
Package metadata that describe a crate

Fields

name: String

Name of the package

version: String

Version of the package

license: Option<String>

Package license

description: Option<String>

Description of the package

documentation: Option<String>

URL of the package documentation

authors: Vec<String>

Authors of the package

Implementations

Source

impl PackageMetadata

pub fn contain_metadata(&self, name: &str) -> bool

Know if a metadata key is present

pub fn get_targets(&self, kind: &str) -> Option<Vec<String>>

Getter of the targets for a specific kind (bin, custom-build)

pub fn is_prosa(&self) -> bool

Know if the package contain ProSA metadata

pub fn get_prosa_proc_metadata(&self) -> Option<HashMap<&str, Metadata>>

Getter of the ProSA Processor or Adaptor if present

pub fn get_prosa_main(&self) -> Vec<String>

Getter of the ProSA main list

pub fn get_prosa_tvf(&self) -> Vec<String>

Getter of the ProSA TVF list

pub fn get_main_version<'a>( &'a self, name: &str, ) -> Option<ComponentVersion<'a>>

Method to get the processor version from its name if it exist

pub fn get_tvf_version<'a>(&'a self, name: &str) -> Option<ComponentVersion<'a>>

Method to get the processor version from its name if it exist

pub fn get_proc_version<'a>( &'a self, name: &str, ) -> Option<ComponentVersion<'a>>

Method to get the processor version from its name if it exist

pub fn get_adaptor_version<'a>( &'a self, name: &str, ) -> Option<ComponentVersion<'a>>

Method to get the adaptor version from its name if it exist

pub fn j2_context(&self, ctx: &mut Context)

Method to add package metadata to a Jinja context